==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/PortfolioAddType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a document to the portfolio.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PortfolioAddType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="PortfolioAddType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice maxOccurs="unbounded">
 *         <element name="file" type="{http://schema.webpdf.de/1.0/operation}PortfolioFileType"/>
 *         <element name="folder" type="{http://schema.webpdf.de/1.0/operation}PortfolioFolderType"/>
 *       </choice>
 *       <attribute name="initialDocumentPath" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="initialFileName" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PortfolioAddType", propOrder = {
    "file",
    "folder"
})
public class PortfolioAddType {

    protected List<PortfolioFileType> file;
    protected List<PortfolioFolderType> folder;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the path/folder where the initially shown document is stored in the portfolio.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "initialDocumentPath")
    protected String initialDocumentPath;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Select the name of the initially shown document.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "initialFileName")
    protected String initialFileName;

    /**
     * Gets the value of the file property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the file property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getFile().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PortfolioFileType }
     * </p>
     * 
     * 
     * @return
     *     The value of the file property.
     */
    public List<PortfolioFileType> getFile() {
        if (file == null) {
            file = new ArrayList<>();
        }
        return this.file;
    }

    public boolean isSetFile() {
        return ((this.file!= null)&&(!this.file.isEmpty()));
    }

    public void unsetFile() {
        this.file = null;
    }

    /**
     * Gets the value of the folder property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the folder property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getFolder().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PortfolioFolderType }
     * </p>
     * 
     * 
     * @return
     *     The value of the folder property.
     */
    public List<PortfolioFolderType> getFolder() {
        if (folder == null) {
            folder = new ArrayList<>();
        }
        return this.folder;
    }

    public boolean isSetFolder() {
        return ((this.folder!= null)&&(!this.folder.isEmpty()));
    }

    public void unsetFolder() {
        this.folder = null;
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the path/folder where the initially shown document is stored in the portfolio.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInitialDocumentPath() {
        if (initialDocumentPath == null) {
            return "";
        } else {
            return initialDocumentPath;
        }
    }

    /**
     * Sets the value of the initialDocumentPath property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getInitialDocumentPath()
     */
    public void setInitialDocumentPath(String value) {
        this.initialDocumentPath = value;
    }

    public boolean isSetInitialDocumentPath() {
        return (this.initialDocumentPath!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Select the name of the initially shown document.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p33647_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p514165_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p888768_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInitialFileName() {
        if (initialFileName == null) {
            return "";
        } else {
            return initialFileName;
        }
    }

    /**
     * Sets the value of the initialFileName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getInitialFileName()
     */
    public void setInitialFileName(String value) {
        this.initialFileName = value;
    }

    public boolean isSetInitialFileName() {
        return (this.initialFileName!= null);
    }

}

==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/PortfolioAddType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Adds a document to the portfolio.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PortfolioAddType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="PortfolioAddType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice maxOccurs="unbounded">
 *         <element name="file" type="{http://schema.webpdf.de/1.0/operation}PortfolioFileType"/>
 *         <element name="folder" type="{http://schema.webpdf.de/1.0/operation}PortfolioFolderType"/>
 *       </choice>
 *       <attribute name="initialDocumentPath" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="initialFileName" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PortfolioAddType", propOrder = {
    "file",
    "folder"
})
public class PortfolioAddType {

    protected List<PortfolioFileType> file;
    protected List<PortfolioFolderType> folder;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the path/folder where the initially shown document is stored in the portfolio.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "initialDocumentPath")
    protected String initialDocumentPath;
    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Select the name of the initially shown document.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "initialFileName")
    protected String initialFileName;

    /**
     * Gets the value of the file property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the file property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getFile().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PortfolioFileType }
     * </p>
     * 
     * 
     * @return
     *     The value of the file property.
     */
    public List<PortfolioFileType> getFile() {
        if (file == null) {
            file = new ArrayList<>();
        }
        return this.file;
    }

    public boolean isSetFile() {
        return ((this.file!= null)&&(!this.file.isEmpty()));
    }

    public void unsetFile() {
        this.file = null;
    }

    /**
     * Gets the value of the folder property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the folder property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getFolder().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PortfolioFolderType }
     * </p>
     * 
     * 
     * @return
     *     The value of the folder property.
     */
    public List<PortfolioFolderType> getFolder() {
        if (folder == null) {
            folder = new ArrayList<>();
        }
        return this.folder;
    }

    public boolean isSetFolder() {
        return ((this.folder!= null)&&(!this.folder.isEmpty()));
    }

    public void unsetFolder() {
        this.folder = null;
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the path/folder where the initially shown document is stored in the portfolio.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInitialDocumentPath() {
        if (initialDocumentPath == null) {
            return "";
        } else {
            return initialDocumentPath;
        }
    }

    /**
     * Sets the value of the initialDocumentPath property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getInitialDocumentPath()
     */
    public void setInitialDocumentPath(String value) {
        this.initialDocumentPath = value;
    }

    public boolean isSetInitialDocumentPath() {
        return (this.initialDocumentPath!= null);
    }

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Select the name of the initially shown document.&#13;
     * &#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p671948_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p683709_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p708536_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
     *                         The "path" and "fileName" parameters follow and implement the glob selection patterns for files and paths. Which is: A portfolio path is defined by "/" separated nested folder names.&#13;
     *                     &lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInitialFileName() {
        if (initialFileName == null) {
            return "";
        } else {
            return initialFileName;
        }
    }

    /**
     * Sets the value of the initialFileName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     * @see #getInitialFileName()
     */
    public void setInitialFileName(String value) {
        this.initialFileName = value;
    }

    public boolean isSetInitialFileName() {
        return (this.initialFileName!= null);
    }

}
